package
Version:
v0.0.0-...-cd18520
Opens a new window with list of versions in this module.
Published: Jul 27, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CniArgs struct {
Name string `json:"name,omitempty"`
}
EnvArgs structure represents inputs sent from each VMI via environment variables
type NetConf struct {
types.NetConf
Args struct {
Cni CniArgs `json:"cni,omitempty"`
} `json:"args,omitempty"`
}
A NetConf structure represents a Multus network attachment definition configuration
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.